Read the content of a crate::document through a crate::connector.
Actions
1 - Get a crate::Context from the input queue.
2 - Extract the crate::DataResult from the crate::Context.
3 - Put the data in the parameter of the crate::connector.
4 - Read bytes from the crate::document through the crate::connector.
5 - Create a new crate::Context and attach the crate::DataResult to it.
6 - Push the new crate::Context into the output queue.
7 - Go to step 1 until the input queue is not empty.
Configuration
| key | alias | Description | Default Value | Possible Values |
|---|---|---|---|---|
| type | - | Required in order to use reader step | reader | reader / read / r |
| connector_type | conn / connector | Connector type to use in order to read a resource | io | See crate::connector |
| document_type | doc / document | Document type to use in order to manipulate the resource | json | See crate::document |
| name | alias | Step name | null | Auto generate alphanumeric value |
| data_type | data | Type of data the reader push in the queue : [ ok / err ] | ok | ok / err |
| concurrency_limit | - | Limit of steps to run in concurrence. | 1 | unsigned number |
Examples
[
{
"type": "reader",
"name": "read_a",
"connector": {
"type": "io"
},
"document": {
"type": "json"
},
"data_type": "ok",
"concurrency_limit": 1
}
...
]